@@ -656,6 +656,15 @@ class SnowflakeTargetConnector(C8Connector):
             ConfigProperty('private_key_passphrase', 'Private Key Passphrase', ConfigAttributeType.STRING, False, False,
                            description='The private key passphrase used for authenticating using Key Pair authentication instead of user/pass.',
                            placeholder_value='my_private_key_passphrase'),
+            ConfigProperty('flush_all_streams', 'Flush All Streams', ConfigAttributeType.BOOLEAN, False, False,
+                           description='Indicates whether to flush all streams (optional).',
+                           default_value='false'),
+            ConfigProperty('parallelism', 'Parallelism', ConfigAttributeType.INT, False, False,
+                           description='Number of parallel threads (optional).',
+                           default_value='1'),
+            ConfigProperty('parallelism_max', 'Parallelism Max', ConfigAttributeType.INT, False, False,
+                           description='Maximum number of parallel threads (optional).',
+                           default_value='10')
         ]
 
     def capabilities(self) -> list[str]:
